# For macro compatibility
%{!?_pkgdocdir:%global _pkgdocdir %{_docdir}/%{name}}

Name:    xdg-desktop-portal
Version: 1.20.3
Release: %mkrel 2
Summary: Portal frontend service to flatpak
Group:   System/Servers
License: LGPLv2+
URL:     https://github.com/flatpak/xdg-desktop-portal/
Source0: https://github.com/flatpak/xdg-desktop-portal/releases/download/%{version}/%{name}-%{version}.tar.xz

BuildRequires: gettext
BuildRequires: gstreamer1.0-tools
BuildRequires: gstreamer1.0-plugins-good
BuildRequires: meson
BuildRequires: pkgconfig(flatpak)
BuildRequires: pkgconfig(fuse3)
BuildRequires: pkgconfig(gio-unix-2.0)
BuildRequires: pkgconfig(gstreamer-pbutils-1.0)
BuildRequires: pkgconfig(gudev-1.0)
BuildRequires: pkgconfig(json-glib-1.0)
BuildRequires: pkgconfig(libgeoclue-2.0)
BuildRequires: pkgconfig(libpipewire-0.3)
BuildRequires: pkgconfig(libportal)
BuildRequires: pkgconfig(libsystemd)
BuildRequires: pkgconfig(umockdev-1.0)
BuildRequires: xmlto
BuildRequires: systemd
BuildRequires: python3-dbusmock
BuildRequires: python3-docutils
BuildRequires: python3-gobject-base
BuildRequires: python3-pytest
BuildRequires: python3-pytest-xdist
BuildRequires: python3-sphinx
BuildRequires: python3-sphinx-copybutton
BuildRequires: python3-sphinx-theme-furo
BuildRequires: python3-sphinxext-opengraph
%{?systemd_requires}
Requires:      dbus
# Required version for icon validator.
Recommends:    flatpak >= 1.2.0
Requires:      geoclue
Requires:      pipewire
Requires:      fuse3

%description
xdg-desktop-portal works by exposing a series of D-Bus interfaces known as
portals under a well-known name (org.freedesktop.portal.Desktop) and object
path (/org/freedesktop/portal/desktop). The portal interfaces include APIs for
file access, opening URIs, printing and others.

%package  devel
Summary:  Development files for %{name}
Group:    Development/Other
Requires: %{name}%{?_isa} = %{version}-%{release}

%description devel
The pkg-config file for %{name}.


%prep
%autosetup -p1


%build
%meson
%meson_build


%install
%meson_install
install -dm 755 %{buildroot}%{_pkgdocdir}
install -pm 644 README.md %{buildroot}%{_pkgdocdir}

# This directory is used by implementations such as xdg-desktop-portal-gtk.
install -dm 755 %{buildroot}%{_datadir}/%{name}/portals

# This directory is used for local system configurations for all users
install -dm 755 %{buildroot}%{_sysconfdir}/%{name}/

%find_lang %{name}


%post
%systemd_user_post %{name}.service
%systemd_user_post xdg-desktop-portal-rewrite-launchers.service
%systemd_user_post xdg-document-portal.service
%systemd_user_post xdg-permission-store.service


%preun
%systemd_user_preun %{name}.service
%systemd_user_preun xdg-desktop-portal-rewrite-launchers.service
%systemd_user_preun xdg-document-portal.service
%systemd_user_preun xdg-permission-store.service


%files -f %{name}.lang
%doc %{_pkgdocdir}
%license COPYING
%dir %{_sysconfdir}/%{name}/
%{_datadir}/dbus-1/interfaces/org.freedesktop.portal.*.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.impl.portal.*.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.host.portal.*.xml
%{_datadir}/dbus-1/services/org.freedesktop.portal.Desktop.service
%{_datadir}/dbus-1/services/org.freedesktop.portal.Documents.service
%{_datadir}/dbus-1/services/org.freedesktop.impl.portal.PermissionStore.service
%{_datadir}/%{name}/
%{_libexecdir}/xdg-desktop-portal
%{_libexecdir}/xdg-desktop-portal-rewrite-launchers
%{_libexecdir}/xdg-desktop-portal-validate-icon
%{_libexecdir}/xdg-desktop-portal-validate-sound
%{_libexecdir}/xdg-document-portal
%{_libexecdir}/xdg-permission-store
%{_userunitdir}/%{name}.service
%{_userunitdir}/xdg-desktop-portal-rewrite-launchers.service
%{_userunitdir}/xdg-document-portal.service
%{_userunitdir}/xdg-permission-store.service
%{_mandir}/man5/portals.conf.5*

%files devel
%{_datadir}/pkgconfig/xdg-desktop-portal.pc


%changelog
* Mon Jul 07 2025 daviddavid <daviddavid> 1.20.3-2.mga10
+ Revision: 2250484
- rebuild for new fuse3 3.17.2

* Thu May 29 2025 daviddavid <daviddavid> 1.20.3-1.mga10
+ Revision: 2186892
- new version 1.20.3

* Mon May 19 2025 daviddavid <daviddavid> 1.20.2-1.mga10
+ Revision: 2184843
- new version 1.20.2

* Fri Apr 11 2025 daviddavid <daviddavid> 1.20.0-1.mga10
+ Revision: 2174711
- new version: 1.20.0

* Fri Feb 14 2025 daviddavid <daviddavid> 1.19.3-1.mga10
+ Revision: 2148847
- new version: 1.19.3

* Thu Jan 23 2025 daviddavid <daviddavid> 1.19.2-1.mga10
+ Revision: 2140673
- new version: 1.19.2

* Fri Nov 29 2024 daviddavid <daviddavid> 1.19.0-1.mga10
+ Revision: 2119826
- new version: 1.19.0

* Sat Aug 17 2024 wally <wally> 1.18.4-2.mga10
+ Revision: 2086797
- provide /etc/xdg-desktop-portal/ for local configurations

* Fri Apr 26 2024 daviddavid <daviddavid> 1.18.4-1.mga10
+ Revision: 2061213
- new version: 1.18.4

* Wed Dec 20 2023 daviddavid <daviddavid> 1.18.2-1.mga10
+ Revision: 2020326
- new version: 1.18.2

* Tue Oct 31 2023 daviddavid <daviddavid> 1.18.1-1.mga10
+ Revision: 2002990
- new version: 1.18.1

* Sun Oct 01 2023 daviddavid <daviddavid> 1.18.0-1.mga10
+ Revision: 1992707
- new version: 1.18.0

* Mon May 01 2023 martinw <martinw> 1.16.0-3.mga9
+ Revision: 1955562
- support OnlyIn key in backend .portal file
   o fix for startup delay on multi-DE installs (mga#31855)

* Sun Apr 30 2023 tmb <tmb> 1.16.0-2.mga9
+ Revision: 1955489
- portal-impl: Only return found implementation if it launched

* Thu Dec 29 2022 daviddavid <daviddavid> 1.16.0-1.mga9
+ Revision: 1927592
- new version: 1.16.0
- switch to meson build system

* Tue Sep 27 2022 neoclust <neoclust> 1.15.0-1.mga9
+ Revision: 1892809
- New version 1.15.0

* Thu Aug 11 2022 neoclust <neoclust> 1.14.6-1.mga9
+ Revision: 1877019
- New version 1.14.6

* Wed Jul 27 2022 luigiwalser <luigiwalser> 1.14.5-1.mga9
+ Revision: 1872479
- 1.14.5

* Sun May 08 2022 wally <wally> 1.14.4-1.mga9
+ Revision: 1856798
- new version 1.14.4
- switch to fuse3

* Mon Apr 25 2022 luigiwalser <luigiwalser> 1.12.4-1.mga9
+ Revision: 1853655
- 1.12.4

* Tue Mar 29 2022 luigiwalser <luigiwalser> 1.12.3-1.mga9
+ Revision: 1832169
- 1.12.3

* Fri Dec 31 2021 luigiwalser <luigiwalser> 1.12.1-1.mga9
+ Revision: 1765614
- 1.12.1

* Mon Sep 27 2021 luigiwalser <luigiwalser> 1.10.1-1.mga9
+ Revision: 1746756
- 1.10.1

* Sat Feb 27 2021 luigiwalser <luigiwalser> 1.8.1-1.mga9
+ Revision: 1693011
- 1.8.1

* Wed Oct 14 2020 luigiwalser <luigiwalser> 1.8.0-1.mga8
+ Revision: 1636020
- 1.8.0

* Tue Aug 18 2020 ovitters <ovitters> 1.7.1-2.mga8
+ Revision: 1614783
- rebuild for flatpak

* Sat Mar 28 2020 daviddavid <daviddavid> 1.7.1-1.mga8
+ Revision: 1561299
- new version: 1.7.1
- remove merged upstream patch

* Tue Mar 10 2020 daviddavid <daviddavid> 1.6.0-1.mga8
+ Revision: 1555246
- new version: 1.6.0
- backport PipeWire 0.3 support

* Sat Feb 15 2020 umeabot <umeabot> 1.4.2-2.mga8
+ Revision: 1526656
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Jun 15 2019 ngompa <ngompa> 1.4.2-1.mga7
+ Revision: 1400067
- Rebase to 1.4.2

* Sat Oct 06 2018 tv <tv> 1.0.2-1.mga7
+ Revision: 1318181
- new release
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Mon Feb 12 2018 ngompa <ngompa> 0.9-1.mga7
+ Revision: 1200573
- Update to 0.9

* Sun Apr 02 2017 ngompa <ngompa> 0.6-1.mga6
+ Revision: 1095713
- Update to 0.6

* Wed Dec 14 2016 ngompa <ngompa> 0.4-2.mga6
+ Revision: 1074879
- imported package xdg-desktop-portal


* Tue Dec 13 2016 Neal Gompa <ngompa13@gmail.com> - 0.4-2
- Port to Mageia

* Thu Dec 01 2016 David King <amigadave@amigadave.com> - 0.4-1
- Update to 0.4

* Fri Sep 02 2016 David King <amigadave@amigadave.com> - 0.3-1
- Update to 0.3

* Fri Jul 29 2016 David King <amigadave@amigadave.com> - 0.2-1
- Update to 0.2 (#1361575)

* Tue Jul 12 2016 David King <amigadave@amigadave.com> - 0.1-2
- Own the portals directory

* Mon Jul 11 2016 David King <amigadave@amigadave.com> - 0.1-1
- Initial Fedora packaging
